django-open-humans — django-open-humans documentation

# django-open-humans

`django-open-humans` is a self-contained application for the Django web framework.

This app includes the models & views needed to do social logins through Open Humans as well as capabilities to message members and access/delete/upload files for them. It manages the Oauth2 procedure and token refreshes.

Contents:

- Introduction
  - Features
  - Example use cases
  - Getting in touch
- Getting Started
  - Installing `django-open-humans`
  - Setting up `django-open-humans`
  - Setting up your Open Humans project
- Interacting with Members
  - Accessing an `OpenHumansMember` object
  - Accessing files for an `OpenHumansMember` object
  - Deleting files for an `OpenHumansMember` object
  - Uploading files for an `OpenHumansMember` object
- Configuration Details
  - Environment variables
- views.py
- models.py

# Indices and tables

- Index
- Module Index
- Search Page